
XEP-0352: Client State Indication
=================================

.. module:: slixmpp.plugins.xep_0352

.. autoclass:: XEP_0352
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0352.stanza
    :members:
    :undoc-members:

